@@ -41,8 +41,14 @@ jags <- function (data, inits, parameters.to.save, model.file = "model.bug",
                                                                   
   if (DIC){parameters.to.save <- c(parameters.to.save, "deviance")}
   
-  m <- jags.model(model.file, data = data, inits = inits, nchain = n.chains, 
+  if(is.null(inits)){
+    m <- jags.model(model.file, data = data, nchain = n.chains, 
       n.adapt = n.adapt)
+  }
+  else{ 
+    m <- jags.model(model.file, data = data, inits=inits, nchain = n.chains, 
+      n.adapt = n.adapt)
+  }
   
   if(n.burnin > 0){
     update(m, n.burnin)
